@@ -127,9 +127,7 @@ class AbstractActionSelector(Action, metaclass=ABCMeta):
     def data_source(self) -> str:
         pass
 
-    def __init__(
-        self, *, name: str, text: str, selected_option: Optional[Option] = None
-    ):
+    def __init__(self, *, name: str, text: str, selected_option: Optional[Option] = None):
         super().__init__(text=text, name=name, subtype="select")
         self.selected_option = selected_option
 
@@ -191,9 +189,7 @@ class ActionChannelSelector(AbstractActionSelector):
 class ActionConversationSelector(AbstractActionSelector):
     data_source = "conversations"
 
-    def __init__(
-        self, name: str, text: str, selected_conversation: Optional[Option] = None
-    ):
+    def __init__(self, name: str, text: str, selected_conversation: Optional[Option] = None):
         """
         Automatically populate the selector with a list of conversations they have in
         the workspace.
@@ -328,8 +324,7 @@ class Attachment(JsonObject):
                 table-like way. For best results, include no more than 2-3 field
                 objects.
             color: Changes the color of the border on the left side of this attachment
-                from the default gray. Can either be one of "good" (green), "warning"
-                (yellow), "danger" (red), or any hex color code (eg. #439FE0)
+                from the default gray. Can be any hex color code (eg. #439FE0)
             markdown_in: An array of field names that should be formatted by
                 markdown syntax - allowed values: "pretext", "text", "fields"
             title: Large title text near the top of the attachment.
@@ -396,13 +391,9 @@ class Attachment(JsonObject):
 
     @EnumValidator("markdown_in", MarkdownFields)
     def markdown_in_valid(self):
-        return not self.markdown_in or all(
-            e in self.MarkdownFields for e in self.markdown_in
-        )
+        return not self.markdown_in or all(e in self.MarkdownFields for e in self.markdown_in)
 
-    @JsonValidator(
-        "color attribute must be 'good', 'warning', 'danger', or a hex color code"
-    )
+    @JsonValidator("color attribute must be 'good', 'warning', 'danger', or a hex color code")
     def color_valid(self) -> bool:
         return (
             self.color is None
