@@ -77,17 +77,13 @@ class BaseClient:
         `https_proxy`, `HTTP_PROXY` or `http_proxy`."""
         self.headers = headers or {}
         """`dict` representing additional request headers to attach to all requests."""
-        self.headers["User-Agent"] = get_user_agent(
-            user_agent_prefix, user_agent_suffix
-        )
+        self.headers["User-Agent"] = get_user_agent(user_agent_prefix, user_agent_suffix)
         self.default_params = {}
         if team_id is not None:
             self.default_params["team_id"] = team_id
         self._logger = logger if logger is not None else logging.getLogger(__name__)
 
-        self.retry_handlers = (
-            retry_handlers if retry_handlers is not None else default_retry_handlers()
-        )
+        self.retry_handlers = retry_handlers if retry_handlers is not None else default_retry_handlers()
 
         if self.proxy is None or len(self.proxy.strip()) == 0:
             env_variable = load_http_proxy_from_env(self._logger)
@@ -170,23 +166,17 @@ class BaseClient:
         _json = req_args["json"] if "json" in req_args else None
         headers = req_args["headers"] if "headers" in req_args else None
         token = params.get("token") if params and "token" in params else None
-        auth = (
-            req_args["auth"] if "auth" in req_args else None
-        )  # Basic Auth for oauth.v2.access / oauth.access
+        auth = req_args["auth"] if "auth" in req_args else None  # Basic Auth for oauth.v2.access / oauth.access
         if auth is not None:
             headers = {}
             if isinstance(auth, str):
                 headers["Authorization"] = auth
             elif isinstance(auth, dict):
                 client_id, client_secret = auth["client_id"], auth["client_secret"]
-                value = b64encode(
-                    f"{client_id}:{client_secret}".encode("utf-8")
-                ).decode("ascii")
+                value = b64encode(f"{client_id}:{client_secret}".encode("utf-8")).decode("ascii")
                 headers["Authorization"] = f"Basic {value}"
             else:
-                self._logger.warning(
-                    f"As the auth: {auth}: {type(auth)} is unsupported, skipped"
-                )
+                self._logger.warning(f"As the auth: {auth}: {type(auth)} is unsupported, skipped")
 
         body_params = {}
         if params:
@@ -204,9 +194,7 @@ class BaseClient:
             additional_headers=headers,
         )
 
-    def _request_for_pagination(
-        self, api_url: str, req_args: Dict[str, Dict[str, Any]]
-    ) -> Dict[str, Any]:
+    def _request_for_pagination(self, api_url: str, req_args: Dict[str, Dict[str, Any]]) -> Dict[str, Any]:
         """This method is supposed to be used only for SlackResponse pagination
 
         You can paginate using Python's for iterator as below:
@@ -258,15 +246,9 @@ class BaseClient:
                 def convert_params(values: dict) -> dict:
                     if not values or not isinstance(values, dict):
                         return {}
-                    return {
-                        k: ("(bytes)" if isinstance(v, bytes) else v)
-                        for k, v in values.items()
-                    }
+                    return {k: ("(bytes)" if isinstance(v, bytes) else v) for k, v in values.items()}
 
-                headers = {
-                    k: "(redacted)" if k.lower() == "authorization" else v
-                    for k, v in additional_headers.items()
-                }
+                headers = {k: "(redacted)" if k.lower() == "authorization" else v for k, v in additional_headers.items()}
                 self._logger.debug(
                     f"Sending a request - url: {url}, "
                     f"query_params: {convert_params(query_params)}, "
@@ -316,14 +298,10 @@ class BaseClient:
                 try:
                     response_body_data = json.loads(response["body"])
                 except json.decoder.JSONDecodeError:
-                    message = _build_unexpected_body_error_message(
-                        response.get("body", "")
-                    )
+                    message = _build_unexpected_body_error_message(response.get("body", ""))
                     raise err.SlackApiError(message, response)
 
-            all_params: Dict[str, Any] = (
-                copy.copy(body_params) if body_params is not None else {}
-            )
+            all_params: Dict[str, Any] = copy.copy(body_params) if body_params is not None else {}
             if query_params:
                 all_params.update(query_params)
             request_args["params"] = all_params  # for backward-compatibility
@@ -342,9 +320,7 @@ class BaseClient:
                 if not f.closed:
                     f.close()
 
-    def _perform_urllib_http_request(
-        self, *, url: str, args: Dict[str, Dict[str, Any]]
-    ) -> Dict[str, Any]:
+    def _perform_urllib_http_request(self, *, url: str, args: Dict[str, Dict[str, Any]]) -> Dict[str, Any]:
         """Performs an HTTP request and parses the response.
 
         Args:
@@ -374,16 +350,10 @@ class BaseClient:
                     filename = "Uploaded file"
                     name_attr = getattr(value, "name", None)
                     if name_attr:
-                        filename = (
-                            name_attr.decode("utf-8")
-                            if isinstance(name_attr, bytes)
-                            else name_attr
-                        )
+                        filename = name_attr.decode("utf-8") if isinstance(name_attr, bytes) else name_attr
                     if "filename" in data:
                         filename = data["filename"]
-                    mimetype = (
-                        mimetypes.guess_type(filename)[0] or "application/octet-stream"
-                    )
+                    mimetype = mimetypes.guess_type(filename)[0] or "application/octet-stream"
                     title = (
                         f'\r\nContent-Disposition: form-data; name="{key}"; filename="{filename}"\r\n'
                         + f"Content-Type: {mimetype}\r\n"
@@ -426,7 +396,29 @@ class BaseClient:
             try:
                 resp = self._perform_urllib_http_request_internal(url, req)
                 # The resp is a 200 OK response
-                return resp
+                if len(self.retry_handlers) > 0:
+                    retry_request = RetryHttpRequest.from_urllib_http_request(req)
+                    body_string = resp["body"] if isinstance(resp["body"], str) else None
+                    body_bytes = body_string.encode("utf-8") if body_string is not None else resp["body"]
+                    body = json.loads(body_string) if body_string is not None and body_string.startswith("{") else {}
+                    retry_response = RetryHttpResponse(
+                        status_code=resp["status"],
+                        headers=resp["headers"],
+                        body=body,
+                        data=body_bytes,
+                    )
+                    for handler in self.retry_handlers:
+                        if handler.can_retry(state=retry_state, request=retry_request, response=retry_response):
+                            if self._logger.level <= logging.DEBUG:
+                                self._logger.info(
+                                    f"A retry handler found: {type(handler).__name__} for {req.method} {req.full_url}"
+                                )
+                            handler.prepare_for_next_attempt(
+                                state=retry_state, request=retry_request, response=retry_response
+                            )
+                            break
+                if retry_state.next_attempt_requested is False:
+                    return resp
 
             except HTTPError as e:
                 # As adding new values to HTTPError#headers can be ignored, building a new dict object here
@@ -434,20 +426,10 @@ class BaseClient:
                 resp = {"status": e.code, "headers": response_headers}
                 if e.code == 429:
                     # for compatibility with aiohttp
-                    if (
-                        "retry-after" not in response_headers
-                        and "Retry-After" in response_headers
-                    ):
-                        response_headers["retry-after"] = response_headers[
-                            "Retry-After"
-                        ]
-                    if (
-                        "Retry-After" not in response_headers
-                        and "retry-after" in response_headers
-                    ):
-                        response_headers["Retry-After"] = response_headers[
-                            "retry-after"
-                        ]
+                    if "retry-after" not in response_headers and "Retry-After" in response_headers:
+                        response_headers["retry-after"] = response_headers["Retry-After"]
+                    if "Retry-After" not in response_headers and "retry-after" in response_headers:
+                        response_headers["Retry-After"] = response_headers["retry-after"]
 
                 # read the response body here
                 charset = e.headers.get_content_charset() or "utf-8"
@@ -459,9 +441,7 @@ class BaseClient:
                 retry_response = RetryHttpResponse(
                     status_code=e.code,
                     headers={k: [v] for k, v in response_headers.items()},
-                    data=response_body.encode("utf-8")
-                    if response_body is not None
-                    else None,
+                    data=response_body.encode("utf-8") if response_body is not None else None,
                 )
                 for handler in self.retry_handlers:
                     if handler.can_retry(
@@ -487,9 +467,7 @@ class BaseClient:
 
             except Exception as err:
                 last_error = err
-                self._logger.error(
-                    f"Failed to send a request to Slack API server: {err}"
-                )
+                self._logger.error(f"Failed to send a request to Slack API server: {err}")
 
                 # Try to find a retry handler for this error
                 retry_request = RetryHttpRequest.from_urllib_http_request(req)
@@ -510,9 +488,7 @@ class BaseClient:
                             response=None,
                             error=err,
                         )
-                        self._logger.info(
-                            f"Going to retry the same request: {req.method} {req.full_url}"
-                        )
+                        self._logger.info(f"Going to retry the same request: {req.method} {req.full_url}")
                         break
 
                 if retry_state.next_attempt_requested is False:
@@ -540,18 +516,14 @@ class BaseClient:
                         HTTPSHandler(context=self.ssl),
                     )
                 else:
-                    raise SlackRequestError(
-                        f"Invalid proxy detected: {self.proxy} must be a str value"
-                    )
+                    raise SlackRequestError(f"Invalid proxy detected: {self.proxy} must be a str value")
 
             # NOTE: BAN-B310 is already checked above
             resp: Optional[HTTPResponse] = None
             if opener:
                 resp = opener.open(req, timeout=self.timeout)  # skipcq: BAN-B310
             else:
-                resp = urlopen(  # skipcq: BAN-B310
-                    req, context=self.ssl, timeout=self.timeout
-                )
+                resp = urlopen(req, context=self.ssl, timeout=self.timeout)  # skipcq: BAN-B310
             if resp.headers.get_content_type() == "application/gzip":
                 # admin.analytics.getFile
                 body: bytes = resp.read()
@@ -595,9 +567,7 @@ class BaseClient:
     # =================================================================
 
     @staticmethod
-    def validate_slack_signature(
-        *, signing_secret: str, data: str, timestamp: str, signature: str
-    ) -> bool:
+    def validate_slack_signature(*, signing_secret: str, data: str, timestamp: str, signature: str) -> bool:
         """
         Slack creates a unique string for your app and shares it with you. Verify
         requests from Slack with confidence by verifying signatures using your
